@@ -282,11 +282,11 @@ namespace Lum {
       return res;
     }
 
-    extern void ToUpper(std::string& string);
-    extern void ToLower(std::string& string);
+    extern LUMAPI void ToUpper(std::string& string);
+    extern LUMAPI void ToLower(std::string& string);
 
-    extern void ToUpper(std::wstring& string);
-    extern void ToLower(std::wstring& string);
+    extern LUMAPI void ToUpper(std::wstring& string);
+    extern LUMAPI void ToLower(std::wstring& string);
 
     extern LUMAPI bool MatchWildcard(const std::wstring& pattern,
                                      const std::wstring& string,
