@@ -24,6 +24,8 @@
 
 #include <Lum/Model/Action.h>
 
+#include <Lum/OS/Theme.h>
+
 #include <Lum/Object.h>
 
 namespace Lum {
@@ -117,6 +119,11 @@ namespace Lum {
                           Base::Model* action,
                           Type type,
                           bool horizontalFlex=false, bool verticalFlex=false);
+    static Button* Create(const std::wstring& text,
+                          Lum::OS::Theme::StockImage image,
+                          Base::Model* action,
+                          Type type,
+                          bool horizontalFlex=false, bool verticalFlex=false);
 
     static Button* CreateOk(Model::Action* action,
                             bool horizontalFlex=false, bool verticalFlex=false);
