@@ -27,7 +27,7 @@
 #include <Lum/Base/Object.h>
 
 #include <Lum/Object.h>
-#include <iostream>
+
 namespace Lum {
   namespace Model {
 
@@ -67,6 +67,9 @@ namespace Lum {
         size_t count;
       };
 
+    private:
+      std::wstring emptyText;
+
     public:
       Table();
       ~Table();
@@ -76,6 +79,9 @@ namespace Lum {
       void NotifyInsert(size_t row, size_t count);
       void NotifyDelete(size_t row, size_t count);
 
+      void SetEmptyText(const std::wstring& text);
+      std::wstring GetEmptyText() const;
+
       virtual size_t GetRows() const = 0;
 
       virtual std::wstring GetString(size_t column, size_t row) const = 0;
@@ -90,79 +96,6 @@ namespace Lum {
 
     typedef Base::Reference<Table> TableRef;
 
-    /**
-      This implementation of the Table interface is obsolete. Don't use it anymore!
-     */
-    class LUMAPI ListTable : public Table
-    {
-    public:
-      class LUMAPI Entry
-      {
-      protected:
-        ListTable *table;
-
-      public:
-        Entry(ListTable* table);
-        virtual ~Entry();
-
-        virtual std::wstring GetString(size_t column) const;
-        virtual Lum::Object* GetObject(size_t column) const;
-        virtual bool IsGreater(const Entry* other, size_t column) const;
-      };
-
-      class LUMAPI StdEntry : public Entry
-      {
-      private:
-        class Cell
-        {
-        public:
-          std::wstring string;
-          Lum::Object  *object;
-
-          Cell();
-        };
-
-      private:
-        std::vector<Cell> row;
-
-      public:
-        StdEntry(ListTable* table);
-        virtual ~StdEntry();
-
-        std::wstring GetString(size_t column) const;
-        Lum::Object* GetObject(size_t column) const;
-        void SetString(size_t column, const std::wstring& string);
-        void SetObject(size_t column, Lum::Object* object);
-      };
-
-    private:
-      mutable std::list<Entry*>           list;
-      mutable std::list<Entry*>::iterator current;
-      mutable size_t                      currentPos;
-
-    public:
-      ListTable();
-      virtual ~ListTable();
-
-      size_t GetRows() const;
-
-      std::wstring GetString(size_t column, size_t row) const;
-      Lum::Object* GetObject(size_t column, size_t row) const;
-
-      Entry* GetEntry(size_t row) const;
-      size_t GetRow(Entry* entry) const;
-      bool Sort(size_t column, bool down=true);
-      // Insert
-      // SwapWithNext
-      void Delete(size_t row);
-      void Prepend(Entry* entry);
-      void Append(Entry* entry);
-      void AppendString(const std::wstring& string);
-      void Clear();
-    };
-
-    typedef Base::Reference<ListTable> ListTableRef;
-
     /**
       Abstract base class for TableModel implementations that wrap stdandard library
       containers.
@@ -186,7 +119,7 @@ namespace Lum {
         {
           // no code
         }
- 
+
         virtual std::wstring GetString(const Iterator& /*iter*/, size_t /*column*/) const
         {
           return L"";
@@ -298,7 +231,7 @@ namespace Lum {
         return GetContainer().size();
       }
 
-      const Element& GetEntry(size_t row) const
+      virtual const Element& GetEntry(size_t row) const
       {
         GotoEntry(row);
 
@@ -308,7 +241,7 @@ namespace Lum {
       /**
         You need to manually call RereshRow after changing the entry!
        */
-      Element& GetEntry(size_t row)
+      virtual Element& GetEntry(size_t row)
       {
         GotoEntry(row);
 
@@ -329,11 +262,10 @@ namespace Lum {
 
       // Insert
       // SwapWithNext
-      Element Delete(size_t row)
+      virtual Element Delete(size_t row)
       {
         GotoEntry(row);
 
-
         ElementType value=*current;
 
         GetContainer().erase(current);
@@ -345,14 +277,14 @@ namespace Lum {
         return value;
       }
 
-      void Prepend(const Element& entry)
+      virtual void Prepend(const Element& entry)
       {
-        GetContainer().push_front(entry);
+        GetContainer().insert(GetContainer().begin(),entry);
         currentPos++;
         NotifyInsert(1,1);
       }
 
-      void Append(const Element& entry)
+      virtual void Append(const Element& entry)
       {
         GetContainer().push_back(entry);
 
@@ -361,7 +293,7 @@ namespace Lum {
         NotifyInsert(GetContainer().size(),1);
       }
 
-      void Clear()
+      virtual void Clear()
       {
         InvalidateCurrent();
 
@@ -378,7 +310,7 @@ namespace Lum {
       /**
         Sort by the given column up or down.
        */
-      bool Sort(size_t /*column*/, bool /*down=true*/)
+      virtual bool Sort(size_t /*column*/, bool /*down=true*/)
       {
         return false;
       }
@@ -443,7 +375,7 @@ namespace Lum {
     };
 
     /**
-      TableModel implementation that wraps an instancance the given container of type
+      TableModel implementation that wraps an instancance of the given container of type
       Container holding elements of type Element.
      */
     template<typename Element, typename Container = std::list<Element> >
@@ -472,6 +404,56 @@ namespace Lum {
       }
     };
 
+    /**
+      TableModel implementation that wraps an instancance of the given container of type
+      Container holding elements of type Element. Elements are of type pointer.
+      Deleting an element using Delete() or Clear() will call the delete operator on
+      this element.
+     */
+    template<typename Element, typename Container = std::list<Element> >
+    class LUMAPI StdPtrTable : public StdTableBaseSorted<Element,Container>
+    {
+
+    private:
+      mutable typename StdTableBase<Element, Container>::ContainerType container;
+
+    public:
+      StdPtrTable(typename StdTableBase<Element, Container>::DataProvider* dataProvider,
+               typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
+       : StdTableBaseSorted<Element,Container>(dataProvider,comparator)
+      {
+        // no code
+      }
+
+      Container& GetContainer()
+      {
+        return container;
+      }
+
+      const Container& GetContainer() const
+      {
+        return container;
+      }
+
+      Element Delete(size_t row)
+      {
+        Element value=StdTableBase<Element,Container>::Delete(row);
+
+        delete value;
+
+        return value;
+      }
+
+      void Clear()
+      {
+        for (size_t i=1; i<=this->GetRows(); i++) {
+          delete this->GetEntry(i);
+        }
+
+        StdTableBase<Element,Container>::Clear();
+      }
+    };
+
     /**
       TableModel implementation that wraps an reference to an instancance the given
       container of type Container holding elements of type Element.
