@@ -52,6 +52,7 @@ namespace Lum {
         Model::ActionRef     menuAction;       //! Triggered if the windo should show its window (embedded app context)
 
         std::wstring         title;            //! Title of window
+        bool                 isInited;         //! true, if the PreInit action has been triggered
         bool                 open;             //! Window is open
         bool                 inEventLoop;      //! True, if window is in event loop
         bool                 shown;            //! Window has been redrawn after open
@@ -139,6 +140,7 @@ namespace Lum {
         bool CursorIsIn() const;
         bool HasFocus() const;
 
+        bool IsInited() const;
         bool Open(bool activate);
         bool IsOpen() const;
         void Close();
