@@ -42,9 +42,9 @@
 namespace Lum {
   namespace OS {
 
-    class Display;
-    class Theme;
-    class Window;
+    class Behaviour; // The display holds a concrete behaviour, but does not know anything about them
+    class Theme;     // The display holds a concrete behaviour, but does not know anything about them
+    class Window;    // Forward declaration to avoid recursive includes
 
     namespace Manager {
       class KeyboardManager;
@@ -499,6 +499,14 @@ namespace Lum {
       virtual Theme* GetTheme() const = 0;
       //@}
 
+      /**
+        @name Behaviour
+        Methods for dealing with configurable behaviour.
+      */
+      //@{
+      virtual Behaviour* GetBehaviour() const = 0;
+      //@}
+
       virtual size_t GetSpaceHorizontal(Space space) const = 0;
       virtual size_t GetSpaceVertical(Space space) const = 0;
 
