@@ -36,7 +36,6 @@ namespace Lum {
 
       private:
         Display     *display;
-        bool        grab;
 
         MouseEvent  oldButton;
         MouseEvent  lastButton;
@@ -69,8 +68,8 @@ namespace Lum {
 
         void RecalcWindowPosition();
 
-        void GrabOn();
-        void GrabOff();
+        void MouseGrabOn();
+        void MouseGrabOff();
 
         void Init();
 
