@@ -49,7 +49,8 @@ namespace Lum {
         typeSplash,
         typeDialog,
         typeMain,
-        typeAuto
+        typeAuto,
+        typeCustom    //! Framework will leave the window allown and set any type hints
       };
 
       enum Position {
@@ -183,6 +184,7 @@ namespace Lum {
         @name Window visibility
       */
       //@{
+      virtual bool IsInited() const = 0;
       virtual bool Open(bool activate=true) = 0;
       virtual void Close() = 0;
       virtual bool IsOpen() const = 0;
