@@ -67,15 +67,16 @@ namespace Lum {
           styleLabel        = 26,
           styleButtonBox    = 27,
           stylePane         = 28,
-          styleDummy        = 29,
+          styleToggleButton = 29,
+          styleDummy        = 30,
 
-          styleMenuBar      = 30,
-          styleMenuPullDown = 31,
-          styleMenu         = 32,
-          styleMenuItem     = 33,
-          stylePopup        = 34,
+          styleMenuBar      = 31,
+          styleMenuPullDown = 32,
+          styleMenu         = 33,
+          styleMenuItem     = 34,
+          stylePopup        = 35,
 
-          styleMax          = 35
+          styleMax          = 36
         };
 
       public:
@@ -201,9 +202,16 @@ namespace Lum {
         bool ShowButtonImages() const;
         bool RequestFingerFriendlyControls() const;
 
+        Lum::Base::Size GetFingerFriendlyMinWidth() const;
+        Lum::Base::Size GetFingerFriendlyMinHeight() const;
+
+        bool ShowKeyShortcuts() const;
+        bool FocusOnEditableControlsOnly() const;
+
         MenuType GetMenuType() const;
         void GetMenuTypeActionPopupOffset(int& x, int& y) const;
         int GetSubMenuHorizontalOffset() const;
+        bool OptimizeMenus() const;
 
         bool SubdialogsAlwaysFlexHoriz() const;
         DialogActionPosition GetDialogActionPosition() const;
