@@ -59,6 +59,7 @@ namespace Lum {
         long        balloonId;
         ::Window    window;
         bool        fullScreen;
+        Atom        customWindowType;
 
       public:
         XIC         xic;
@@ -115,6 +116,8 @@ namespace Lum {
         bool IsFullScreen() const;
 
         bool SetOpacity(double opacity);
+        
+        void SetCustomWindowType(Atom type);
       };
     }
   }
