@@ -22,6 +22,7 @@
 
 #include <list>
 #include <map>
+#include <set>
 
 #include <Lum/Base/Object.h>
 #include <Lum/Base/Size.h>
@@ -293,6 +294,9 @@ namespace Lum {
                                   size_t value,
                                   const OS::FontRef& font=::Lum::OS::FontRef());
 
+    virtual Object* SetConstraint(Constraint constraint,
+                                  const Base::Size& size);
+
     virtual Object* SetWidth(Base::Size::Mode mode,
                              size_t value,
                              const OS::FontRef& font=::Lum::OS::FontRef());
@@ -313,6 +317,14 @@ namespace Lum {
     virtual Object* SetMaxHeight(Base::Size::Mode mode,
                                  size_t value,
                                  const OS::FontRef& font=::Lum::OS::FontRef());
+
+    virtual Object* SetMinWidth(const Base::Size& size);
+    virtual Object* SetMinHeight(const Base::Size& size);
+    virtual Object* SetWidth(const Base::Size& size);
+    virtual Object* SetHeight(const Base::Size& size);
+    virtual Object* SetMaxWidth(const Base::Size& size);
+    virtual Object* SetMaxHeight(const Base::Size& size);
+
     //@}
 
     /**
@@ -470,6 +482,13 @@ namespace Lum {
     virtual bool HandleMouseEvent(const OS::MouseEvent& event);
     virtual bool HandleKeyEvent(const OS::KeyEvent& event);
     //@}
+
+    /**
+      @name Mouse and keyboard input callbacks
+    */
+    //@{
+    virtual void GetModels(std::set<Base::Model*>& models);
+    //@}
   };
 
   /**
