@@ -122,6 +122,7 @@ namespace Lum {
     bool             selected;         //! The is currently a selection
     bool             readOnly;         //! The control is read only
     bool             cursorVisible;    //! The cursor is currently visible (=> cursor blinking)
+    bool             showClearButton;  //! Show a clear button as part of control
     Mode             mode;             //! Draw mode to be used for drawing the text
     Model::ActionRef blinkAction;      //! Timer action for triggering cursor blinking
 
@@ -182,8 +183,9 @@ namespace Lum {
     void SetFocusInAction(Model::Action* action);
     void SetFocusOutAction(Model::Action* action);
 
-    void SetMode(Mode mode);
-    void SetAlignment(Alignment alignment);
+    String* SetMode(Mode mode);
+    String* SetAlignment(Alignment alignment);
+    String* ShowClearButton(bool show);
 
     // Getter
     Model::Action* GetCursorUpAction() const;
