@@ -131,6 +131,12 @@ namespace Lum {
     void CalcSize();
 
     void Draw(int x, int y, size_t w, size_t h);
+
+    static Text* Create(const std::wstring& text,
+                        bool horizontalFlex=false, bool verticalFlex=false);
+    static Text* Create(const std::wstring& text,
+                        Alignment alignment,
+                        bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
