@@ -212,12 +212,12 @@ namespace Lum {
       case menuEdit:
         return GetLocalizedLibText(L"MENU_EDIT",L"_Edit");
       case menuEditSettings:
-        return GetLocalizedLibText(L"MENU_EDIT_SETTINGS",L"_Settings");
+        return GetLocalizedLibText(L"MENU_EDIT_SETTINGS",L"_Settings...");
 
       case menuHelp:
         return GetLocalizedLibText(L"MENU_HELP",L"_Help");
       case menuHelpHelp:
-        return GetLocalizedLibText(L"MENU_HELP_HELP",L"Help");
+        return GetLocalizedLibText(L"MENU_HELP_HELP",L"Help...");
       case menuHelpAbout:
         return GetLocalizedLibText(L"MENU_HELP_ABOUT",L"About...");
 
