@@ -64,8 +64,10 @@ namespace Lum {
       SetBackground(OS::display->GetFill(OS::Display::comboBackgroundFillIndex));
     }
 
-    SetCanFocus(true);
-    RequestFocus();
+    if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+      SetCanFocus(true);
+      RequestFocus();
+    }
     SetRedrawOnMouseActive(true);
 
     value->SetParent(this);
@@ -169,12 +171,8 @@ namespace Lum {
     if (editable) {
       OS::ImageRef image=OS::display->GetImage(OS::Display::comboEditButtonImageIndex);
 
-      minWidth=image->GetWidth();
-
-      width=minWidth;
-
-      minWidth+=value->GetOMinWidth();
-      minWidth+=value->GetOWidth();
+      minWidth=image->GetWidth()+value->GetOMinWidth();
+      width=image->GetWidth()+value->GetOWidth();
 
       minHeight=std::max(value->GetOMinHeight(),
                          image->GetHeight());
@@ -231,7 +229,7 @@ namespace Lum {
     combo->table->SetTableView(new Table());
     combo->table->SetFlex(true,true);
     combo->table->SetMinHeight(Base::Size::stdCharHeight,1);
-    combo->table->SetMaxWidth(Base::Size::workVRel,40);
+    combo->table->SetMaxWidth(Base::Size::workHRel,80);
     combo->table->SetMaxHeight(Base::Size::workVRel,40);
     combo->table->GetTableView()->SetAutoFitColumns(true);
     combo->table->SetHeaderModel(combo->headerModel);
@@ -362,13 +360,12 @@ namespace Lum {
       }
     }
 
-    value->Layout();
-
     Control::Layout();
   }
 
   void Combo::PrepareForBackground(OS::DrawInfo* draw)
   {
+    draw->selected=false;
     draw->activated=IsMouseActive();
     draw->focused=HasFocus();
     draw->disabled=!(GetModel()!=NULL) || GetModel()->IsNull() || !GetModel()->IsEnabled();
@@ -376,8 +373,6 @@ namespace Lum {
 
   void Combo::Draw(int x, int y, size_t w, size_t h)
   {
-    OS::DrawInfo *draw=GetDrawInfo();
-
     Control::Draw(x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
@@ -386,6 +381,9 @@ namespace Lum {
 
     /* --- */
 
+    OS::DrawInfo *draw=GetDrawInfo();
+
+    draw->selected=false;
     draw->activated=IsMouseActive();
     draw->focused=HasFocus();
     draw->disabled=!(GetModel()!=NULL) || GetModel()->IsNull() || !GetModel()->IsEnabled();
@@ -395,12 +393,9 @@ namespace Lum {
 
       if (imageRight) {
         int    bx,by;
-        size_t bw,bh;
 
         bx=this->x+value->GetOWidth();
         by=this->y;
-        bw=image->GetWidth();
-        bh=height;
 
         image->Draw(draw,
                     bx,by,
@@ -471,13 +466,17 @@ namespace Lum {
     if (editable && value!=NULL) {
       value->SetShowFocus(false);
     }
+
     Control::HideFocus();
   }
 
   void Combo::Hide()
   {
     if (visible) {
-      value->Hide();
+      if (value!=NULL) {
+        value->Hide();
+      }
+
       Control::Hide();
     }
   }
