@@ -187,6 +187,28 @@ namespace Lum {
       return Base::WStringToNumber(this->value,value);
     }
 
+    bool Node::GetValue(float& value) const
+    {
+      if (!HasValue()) {
+        return false;
+      }
+
+      std::string tmp=Base::WStringToString(this->value);
+
+      return sscanf(tmp.c_str(),"%f",&value)==1;
+    }
+
+    bool Node::GetValue(double& value) const
+    {
+      if (!HasValue()) {
+        return false;
+      }
+
+      std::string tmp=Base::WStringToString(this->value);
+
+      return sscanf(tmp.c_str(),"%lf",&value)==1;
+    }
+
     void Node::SetValue(const std::wstring& value, bool multiline)
     {
       hasValue=true;
