@@ -309,6 +309,9 @@ namespace Lum {
     {
       SetBackground(OS::display->GetFill(OS::Display::listboxBackgroundFillIndex));
 
+      SetClipFromParent(true);
+      //SetBackground(new OS::EmptyFill());
+
       SetCanFocus(true);
       RequestFocus();
       SetRequestsKeyboard(true);
@@ -324,6 +327,87 @@ namespace Lum {
       delete drawBuffer;
     }
 
+    bool Edit::CanExecuteAction(const Base::Datatype& type,
+                                Base::DataExchangeObject::ExchangeAction action) const
+    {
+      if (!type.Matches(Lum::Base::Datatype::text)) {
+        return false;
+      }
+
+      switch (action) {
+      case actionMove:
+        return model.Valid() && !model->IsReadOnly() && IsSelected();
+        break;
+      case actionCopy:
+        return model.Valid() && IsSelected();
+        break;
+      case actionInsert:
+        return model.Valid() && !model->IsReadOnly();
+        break;
+      default:
+        return false;
+      }
+    }
+
+    bool Edit::ExecuteAction(const Base::Datatype& type,
+                             Base::Data& data,
+                             Base::DataExchangeObject::ExchangeAction action)
+    {
+      std::wstring text;
+      BufferRef    buffer;
+
+      if (!CanExecuteAction(type,action)) {
+        return false;
+      }
+
+
+      switch (action) {
+      case actionInsert:
+        text=data.GetText();
+
+        if (text.length()==0) {
+          return false;
+        }
+        model->NewUndoGroup();
+        DeleteSelection();
+        model->Insert(cursor,text);
+        MakeCursorVisible(cursor);
+        ExecutePost();
+        return true;
+      case actionCopy:
+        buffer=model->CopyArea(GetStartMark(),GetEndMark());
+
+        if (!buffer.Valid()) {
+          return false;
+        }
+
+        data.SetText(buffer->GetText());
+        return true;
+      case actionMove:
+        buffer=model->CopyArea(GetStartMark(),GetEndMark());
+
+        if (!buffer.Valid()) {
+          return false;
+        }
+
+        data.SetText(buffer->GetText());
+      return true;
+      default:
+        return false;
+      }
+    }
+
+    bool Edit::PostprocessAction(Base::DataExchangeObject::ExchangeAction action)
+    {
+      if (!model.Valid() || action!=actionMove || !IsSelected()) {
+        return false;
+      }
+
+      DeleteSelection();
+
+      return true;
+    }
+
     Config* Edit::GetConfig() const
     {
       return config.Get();
@@ -1114,22 +1198,19 @@ namespace Lum {
       }
     }
 
-    void Edit::UpdateCounts()
+    void Edit::UpdateDimensions()
     {
-      /*
-      msg : T.StatusChangedMsg;
+      if (model.Valid() && model->GetLines()>0) {
+        vAdjustment->Set(GetFirstVisiblePos(),
+                         GetLastVisiblePos()-GetFirstVisiblePos()+1,
+                         model->GetLines());
 
-      update.edit:=e;
-      NEW(msg);
-      update.msg:=msg;
-      e.Send(update,updateMsg);
-      */
-
-      vAdjustment->Set(GetFirstVisiblePos(),
-                       GetLastVisiblePos()-GetFirstVisiblePos()+1,
-                       model->GetLines());
-
-      hAdjustment->Set(horizOffset+1,width,32000);
+        hAdjustment->Set(horizOffset+1,width,32000);
+      }
+      else {
+        hAdjustment->SetInvalid();
+        vAdjustment->SetInvalid();
+      }
     }
 
     /**
@@ -1241,7 +1322,7 @@ namespace Lum {
         draw->PopForeground();
       }
 
-      UpdateCounts();
+      UpdateDimensions();
     }
 
     bool Edit::CanScrollLeft() const
@@ -1519,7 +1600,9 @@ namespace Lum {
           assert(false);
         }
       }
-      else if (true/*D.display.RegisterSelection(e,e.GetWindow())*/) {
+      else {
+        OS::display->RegisterSelection(this,GetWindow());
+
         this->markB=model->GetOrCreateCursor(L"markB",0);
         this->markB->Goto(cursor);
         markA=GetStartMark();
@@ -1647,11 +1730,6 @@ namespace Lum {
         moveCursor=false;
         horizOffset=0;
 
-        /*
-        IF IsSelected() & D.display.RegisterSelection(e,GetWindow()) THEN
-        END;
-        */
-
         TriggerResolveConfigAction();
         TriggerPropertyChangedAction();
       }
@@ -1701,14 +1779,6 @@ namespace Lum {
 
       OS::DrawInfo *draw=GetDrawInfo();
 
-      if (background.Valid() && background->HasBorder()) {
-        draw->PushClipBegin(x,y,w,h);
-        draw->SubClipRegion(this->x,this->y,this->width,this->height);
-        draw->PushClipEnd();
-        DrawBackground(x,y,w,h);
-        draw->PopClip();
-      }
-
       /* --- */
 
       if (!Intersect(x,y,w,h)) {
@@ -1863,8 +1933,8 @@ namespace Lum {
 
         qualifier= event.qualifier & ~(OS::qualifierShiftLeft|OS::qualifierShiftRight|OS::qualifierShift|OS::qualifierCapsLock);
         if (!event.text.empty() && !(name==event.text && qualifier!=0) && event.text[0]>=32) {
-          DeleteSelection();
           model->NewUndoGroup();
+          DeleteSelection();
           model->Insert(cursor,event.text);
           MakeCursorVisible(cursor);
           ExecutePost();
