@@ -19,7 +19,7 @@
 
 #include <Lum/FuelGauge.h>
 
-#include <math.h>
+#include <cmath>
 
 #include <Lum/Base/String.h>
 
@@ -44,10 +44,11 @@ namespace Lum {
   {
     minWidth=2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder)+
              3*font->StringWidth(L"m",OS::Font::normal);
-    minHeight=font->height+2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
+    minHeight=font->pixelHeight+2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
 
     width=minWidth;
     height=minHeight;
+    SetBackground(OS::display->GetFill(OS::Display::hprogressBackgroundFillIndex));
 
     Control::CalcSize();
   }
