@@ -32,404 +32,327 @@
 
 namespace Lum {
 
-  /* ---------- MenuDesc stuff ------------------*/
+  size_t GetValidItemsCount(const std::list<Def::MenuItem*>& items,
+                            const std::set<Base::Model*>& excludes);
 
-  MenuItemDesc::MenuItemDesc()
+  bool WillFoldSubItems(const std::list<Def::MenuItem*>& items,
+                        const std::set<Base::Model*>& excludes)
   {
-    // no code
-  }
+    size_t currentItemsCount=0;
+    size_t subItemsCount=0;
 
-  MenuItemDesc::~MenuItemDesc()
-  {
-    // no code
-  }
-
-  MenuDesc::MenuDesc()
-  {
-    // no code
-  }
-
-  MenuDesc::MenuDesc(const std::wstring& title)
-  {
-    // no code
-  }
-
-  MenuDesc::~MenuDesc()
-  {
-    for (MenuItemList::const_iterator iter=items.begin();
+    for (std::list<Def::MenuItem*>::const_iterator iter=items.begin();
          iter!=items.end();
          ++iter) {
-      delete *iter;
-    }
-  }
-
-  MenuDesc* MenuDesc::AddMenuItem(MenuItemDesc* menuItem)
-  {
-    items.push_back(menuItem);
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
-                                        Model::Action* action)
-  {
-    AddMenuItem(new MenuItemActionDesc(label,NULL,0,L"",action));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
-                                        OS::Image* image,
-                                        Model::Action* action)
-  {
-    AddMenuItem(new MenuItemActionDesc(label,image,0,L"",action));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
-                                        unsigned long qualifier, const std::wstring& key,
-                                        Model::Action* action)
-  {
-    AddMenuItem(new MenuItemActionDesc(label,NULL,qualifier,key,action));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemAction(const std::wstring& label,
-                                        OS::Image* image,
-                                        unsigned long qualifier, const std::wstring& key,
-                                        Model::Action* action)
-  {
-    AddMenuItem(new MenuItemActionDesc(label,image,qualifier,key,action));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
-                                      Model::Boolean* boolean)
-  {
-    AddMenuItem(new MenuItemBoolDesc(label,NULL,0,L"",boolean));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
-                                      OS::Image* image,
-                                      Model::Boolean* boolean)
-  {
-    AddMenuItem(new MenuItemBoolDesc(label,image,0,L"",boolean));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
-                                      unsigned long qualifier, const std::wstring& key,
-                                      Model::Boolean* boolean)
-  {
-    AddMenuItem(new MenuItemBoolDesc(label,NULL,qualifier,key,boolean));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemBool(const std::wstring& label,
-                                      OS::Image* image,
-                                      unsigned long qualifier, const std::wstring& key,
-                                      Model::Boolean* boolean)
-  {
-    AddMenuItem(new MenuItemBoolDesc(label,image,qualifier,key,boolean));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
-                                       Model::SizeT* model,
-                                       size_t index)
-  {
-    AddMenuItem(new MenuItemRadioDesc(label,NULL,0,L"",model,index));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
-                                       OS::Image* image,
-                                       Model::SizeT* model,
-                                       size_t index)
-  {
-    AddMenuItem(new MenuItemRadioDesc(label,image,0,L"",model,index));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
-                                       unsigned long qualifier, const std::wstring& key,
-                                       Model::SizeT* model,
-                                       size_t index)
-  {
-    AddMenuItem(new MenuItemRadioDesc(label,NULL,qualifier,key,model,index));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemRadio(const std::wstring& label,
-                                       OS::Image* image,
-                                       unsigned long qualifier, const std::wstring& key,
-                                       Model::SizeT* model,
-                                       size_t index)
-  {
-    AddMenuItem(new MenuItemRadioDesc(label,image,qualifier,key,model,index));
-
-    return this;
-  }
-
-  MenuDesc* MenuDesc::AddMenuItemSub(const std::wstring& label)
-  {
-    MenuDesc* sub=new MenuDesc();
-
-    AddMenuItem(new MenuItemSubDesc(label,sub));
-
-    return sub;
-  }
-
-  MenuDesc* MenuDesc::AddSeparator()
-  {
-    AddMenuItem(new MenuItemSeparatorDesc());
-
-    return this;
-  }
-
-  const MenuDesc::MenuItemList& MenuDesc::GetItems() const
-  {
-    return items;
-  }
-
-  MenuItemSubDesc::MenuItemSubDesc(const std::wstring& label,
-                                   MenuDesc* menu)
-   : label(label),
-     menu(menu)
-  {
-    // no code
-  }
-
-  MenuItemSubDesc::~MenuItemSubDesc()
-  {
-    delete menu;
-  }
-
-  std::wstring MenuItemSubDesc::GetLabel() const
-  {
-    return label;
-  }
-
-  MenuDesc* MenuItemSubDesc::GetMenuDesc() const
-  {
-    return menu;
-  }
-
-  MenuItemSeparatorDesc::MenuItemSeparatorDesc()
-  {
-    // no code
-  }
-
-  MenuItemActionDesc::MenuItemActionDesc(const std::wstring& label,
-                                         OS::Image* image,
-                                         unsigned long qualifier, const std::wstring& key,
-                                         Model::Action* action)
-  : label(label),
-    image(image),
-    qualifier(qualifier),
-    key(key),
-    action(action)
-  {
-    // no code
-  }
-
-  std::wstring MenuItemActionDesc::GetLabel() const
-  {
-    return label;
-  }
-
-  OS::Image* MenuItemActionDesc::GetImage() const
-  {
-    return image;
-  }
-
-  unsigned long MenuItemActionDesc::GetQualifier() const
-  {
-    return qualifier;
-  }
-
-  std::wstring MenuItemActionDesc::GetKey() const
-  {
-    return key;
-  }
-
-  Model::Action* MenuItemActionDesc::GetAction() const
-  {
-    return action;
-  }
-
-  MenuItemBoolDesc::MenuItemBoolDesc(const std::wstring& label,
-                                     OS::Image* image,
-                                     unsigned long qualifier, const std::wstring& key,
-                                     Model::Boolean* boolean)
-  : label(label),
-    image(image),
-    qualifier(qualifier),
-    key(key),
-    boolean(boolean)
-  {
-    // no code
-  }
-
-  std::wstring MenuItemBoolDesc::GetLabel() const
-  {
-    return label;
-  }
-
-  OS::Image* MenuItemBoolDesc::GetImage() const
-  {
-    return image;
-  }
-
-  unsigned long MenuItemBoolDesc::GetQualifier() const
-  {
-    return qualifier;
-  }
-
-  std::wstring MenuItemBoolDesc::GetKey() const
-  {
-    return key;
-  }
-
-  Model::Boolean* MenuItemBoolDesc::GetBoolean() const
-  {
-    return boolean;
-  }
-
-  MenuItemRadioDesc::MenuItemRadioDesc(const std::wstring& label,
-                                       OS::Image* image,
-                                       unsigned long qualifier, const std::wstring& key,
-                                       Model::SizeT* model,
-                                       size_t index)
-  : label(label),
-    image(image),
-    qualifier(qualifier),
-    key(key),
-    model(model),
-    index(index)
-  {
-    // no code
-  }
-
-  std::wstring MenuItemRadioDesc::GetLabel() const
-  {
-    return label;
-  }
-
-  OS::Image* MenuItemRadioDesc::GetImage() const
-  {
-    return image;
-  }
-
-  unsigned long MenuItemRadioDesc::GetQualifier() const
-  {
-    return qualifier;
-  }
-
-  std::wstring MenuItemRadioDesc::GetKey() const
-  {
-    return key;
-  }
-
-  Model::SizeT* MenuItemRadioDesc::GetModel() const
-  {
-    return model;
-  }
-
-  size_t MenuItemRadioDesc::GetIndex() const
-  {
-    return index;
-  }
-
-  Menu* ConvertToMenu(MenuDesc* menuDesc)
-  {
-    Menu *menu=new Menu();
-
-    for (MenuDesc::MenuItemList::const_iterator iter=menuDesc->GetItems().begin();
-         iter!=menuDesc->GetItems().end();
-         ++iter) {
       assert((*iter)!=NULL);
 
-      if (dynamic_cast<MenuItemSubDesc*>(*iter)!=NULL) {
-        MenuItemSubDesc *sub=dynamic_cast<MenuItemSubDesc*>(*iter);
+      if (dynamic_cast<Def::Menu*>(*iter)!=NULL) {
+        Def::Menu *sub=dynamic_cast<Def::Menu*>(*iter);
 
-        menu->AddSubMenu(sub->GetLabel(),ConvertToMenu(sub->GetMenuDesc()));
+        if (sub->GetItems().size()==1 &&
+            Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          currentItemsCount++;
+        }
+        else {
+          subItemsCount+=GetValidItemsCount(sub->GetItems(),excludes);
+        }
       }
-      else if (dynamic_cast<MenuItemActionDesc*>(*iter)!=NULL) {
-        MenuItemActionDesc *action=dynamic_cast<MenuItemActionDesc*>(*iter);
+      else if (dynamic_cast<Def::MenuAction*>(*iter)!=NULL) {
+        Def::MenuAction *action=dynamic_cast<Def::MenuAction*>(*iter);
 
-        menu->AddActionItem(action->GetLabel(),
-                            /*action->GetImage(),*/
-                            action->GetAction(),
-                            action->GetQualifier(),action->GetKey());
-      }
-      else if (dynamic_cast<MenuItemBoolDesc*>(*iter)!=NULL) {
-        MenuItemBoolDesc *boolean=dynamic_cast<MenuItemBoolDesc*>(*iter);
+        if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          if (excludes.find(action->GetAction().GetAction())!=excludes.end()) {
+            continue;
+          }
+        }
 
-        menu->AddBoolItem(boolean->GetLabel(),
-                            /*bool->GetImage(),*/
-                          boolean->GetBoolean(),
-                          boolean->GetQualifier(),
-                          boolean->GetKey());
+        currentItemsCount++;
       }
-      else if (dynamic_cast<MenuItemRadioDesc*>(*iter)!=NULL) {
-        MenuItemRadioDesc *radio=dynamic_cast<MenuItemRadioDesc*>(*iter);
+      else if (dynamic_cast<Def::MenuBoolean*>(*iter)!=NULL) {
+        Def::MenuBoolean *boolean=dynamic_cast<Def::MenuBoolean*>(*iter);
 
-        menu->AddRadioItem(radio->GetLabel(),
-                            /*radio->GetImage(),*/
-                           radio->GetModel(),
-                           radio->GetIndex(),
-                           radio->GetQualifier(),
-                           radio->GetKey());
+        if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          if (excludes.find(boolean->GetBoolean().GetBoolean())!=excludes.end()) {
+            continue;
+          }
+        }
+
+        currentItemsCount++;
       }
-      else if (dynamic_cast<MenuItemSeparatorDesc*>(*iter)!=NULL) {
-        menu->AddSeparator();
+      else if (dynamic_cast<Def::MenuOneOfN*>(*iter)!=NULL) {
+        Def::MenuOneOfN *oneOfN=dynamic_cast<Def::MenuOneOfN*>(*iter);
+
+        if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          if (excludes.find(oneOfN->GetOneOfN().GetValue())!=excludes.end()) {
+            continue;
+          }
+        }
+
+        currentItemsCount+=oneOfN->GetOneOfN().GetChoices().size();
+      }
+      else if (dynamic_cast<Def::MenuSeparator*>(*iter)!=NULL) {
+        if (!Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          currentItemsCount++;
+        }
       }
       else {
         assert(false);
       }
     }
 
+    return Lum::OS::display->GetTheme()->OptimizeMenus() &&
+           currentItemsCount+subItemsCount<=Lum::OS::display->GetTheme()->MaxPopupMenuEntries();
+  }
+
+  size_t GetValidItemsCount(const std::list<Def::MenuItem*>& items,
+                            const std::set<Base::Model*>& excludes)
+  {
+    size_t result=0;
+    bool   foldSubItems=WillFoldSubItems(items,excludes);
+
+    for (std::list<Def::MenuItem*>::const_iterator iter=items.begin();
+         iter!=items.end();
+         ++iter) {
+      assert((*iter)!=NULL);
+      if (dynamic_cast<Def::Menu*>(*iter)!=NULL) {
+        Def::Menu *sub=dynamic_cast<Def::Menu*>(*iter);
+
+        if (sub->GetItems().size()>0) {
+          if (sub->GetItems().size()==1 &&
+              Lum::OS::display->GetTheme()->OptimizeMenus()) {
+            result++;
+          }
+          else if (foldSubItems) {
+            result+=GetValidItemsCount(sub->GetItems(),excludes);
+          }
+          else {
+            result+=1+GetValidItemsCount(sub->GetItems(),excludes);
+          }
+        }
+      }
+      else if (dynamic_cast<Def::MenuAction*>(*iter)!=NULL) {
+        Def::MenuAction *action=dynamic_cast<Def::MenuAction*>(*iter);
+
+        if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          if (excludes.find(action->GetAction().GetAction())!=excludes.end()) {
+            continue;
+          }
+        }
+
+        result++;
+      }
+      else if (dynamic_cast<Def::MenuBoolean*>(*iter)!=NULL) {
+        Def::MenuBoolean *boolean=dynamic_cast<Def::MenuBoolean*>(*iter);
+
+        if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          if (excludes.find(boolean->GetBoolean().GetBoolean())!=excludes.end()) {
+            continue;
+          }
+        }
+
+        result++;
+      }
+      else if (dynamic_cast<Def::MenuOneOfN*>(*iter)!=NULL) {
+        Def::MenuOneOfN *oneOfN=dynamic_cast<Def::MenuOneOfN*>(*iter);
+
+        if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          if (excludes.find(oneOfN->GetOneOfN().GetValue())!=excludes.end()) {
+            continue;
+          }
+        }
+
+        result+=oneOfN->GetOneOfN().GetChoices().size();
+      }
+      else if (dynamic_cast<Def::MenuSeparator*>(*iter)!=NULL) {
+        if (!Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          result++;
+        }
+      }
+      else {
+        assert(false);
+      }
+    }
+
+    return result;
+  }
+
+  void ConvertItem(Menu* menu, Def::MenuItem* item,
+                   const std::set<Base::Model*>& excludes, bool foldSubItems)
+  {
+    if (dynamic_cast<Def::Menu*>(item)!=NULL) {
+      Def::Menu *sub=dynamic_cast<Def::Menu*>(item);
+      size_t subCount=GetValidItemsCount(sub->GetItems(),excludes);
+
+      if (subCount>0) {
+        if (subCount==1 &&
+            Lum::OS::display->GetTheme()->OptimizeMenus()) {
+          ConvertItem(menu,sub->GetItems().front(),excludes,true);
+        }
+        else if (foldSubItems) {
+          for (std::list<Def::MenuItem*>::const_iterator s=sub->GetItems().begin();
+               s!=sub->GetItems().end();
+               ++s) {
+            ConvertItem(menu,*s,excludes,true);
+          }
+        }
+        else {
+          menu->AddSubMenu(sub->GetDesc().GetLabel(),
+                           ConvertToMenu(sub,excludes));
+        }
+      }
+    }
+    else if (dynamic_cast<Def::MenuAction*>(item)!=NULL) {
+      Def::MenuAction *action=dynamic_cast<Def::MenuAction*>(item);
+
+      if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+        if (excludes.find(action->GetAction().GetAction())!=excludes.end()) {
+          return;
+        }
+      }
+
+      if (action->GetAction().GetDesc().HasShortcut()) {
+      menu->AddActionItem(action->GetAction().GetDesc().GetLabel(),
+                          /*action->GetImage(),*/
+                          action->GetAction().GetAction(),
+                          action->GetAction().GetDesc().GetShortcutQualifier(),
+                          action->GetAction().GetDesc().GetShortcutKey());
+      }
+      else {
+        menu->AddActionItem(action->GetAction().GetDesc().GetLabel(),
+                            /*action->GetImage(),*/
+                            action->GetAction().GetAction());
+      }
+    }
+    else if (dynamic_cast<Def::MenuBoolean*>(item)!=NULL) {
+      Def::MenuBoolean *boolean=dynamic_cast<Def::MenuBoolean*>(item);
+
+      if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+        if (excludes.find(boolean->GetBoolean().GetBoolean())!=excludes.end()) {
+          return;
+        }
+      }
+
+      if (boolean->GetBoolean().GetDesc().HasShortcut()) {
+        menu->AddBoolItem(boolean->GetBoolean().GetDesc().GetLabel(),
+                          /*action->GetImage(),*/
+                          boolean->GetBoolean().GetBoolean(),
+                            boolean->GetBoolean().GetDesc().GetShortcutQualifier(),
+                            boolean->GetBoolean().GetDesc().GetShortcutKey());
+      }
+      else {
+        menu->AddBoolItem(boolean->GetBoolean().GetDesc().GetLabel(),
+                          /*action->GetImage(),*/
+                          boolean->GetBoolean().GetBoolean());
+      }
+    }
+    else if (dynamic_cast<Def::MenuOneOfN*>(item)!=NULL) {
+      Def::MenuOneOfN *oneOfN=dynamic_cast<Def::MenuOneOfN*>(item);
+
+      if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+        if (excludes.find(oneOfN->GetOneOfN().GetValue())!=excludes.end()) {
+          return;
+        }
+      }
+
+      for (std::list<Def::OneOfN::Choice>::const_iterator choice=oneOfN->GetOneOfN().GetChoices().begin();
+           choice!=oneOfN->GetOneOfN().GetChoices().end();
+           ++choice) {
+        if (choice->GetDesc().HasShortcut()) {
+          menu->AddRadioItem(choice->GetDesc().GetLabel(),
+                             /*radio->GetImage(),*/
+                             oneOfN->GetOneOfN().GetValue(),
+                             choice->GetValue(),
+                             choice->GetDesc().GetShortcutQualifier(),
+                             choice->GetDesc().GetShortcutKey());
+        }
+        else {
+          menu->AddRadioItem(choice->GetDesc().GetLabel(),
+                             /*radio->GetImage(),*/
+                             oneOfN->GetOneOfN().GetValue(),
+                             choice->GetValue());
+        }
+      }
+    }
+    else if (dynamic_cast<Def::MenuSeparator*>(item)!=NULL) {
+      if (Lum::OS::display->GetTheme()->OptimizeMenus()) {
+        return;
+      }
+
+      menu->AddSeparator();
+    }
+    else {
+      assert(false);
+    }
+  }
+
+  Menu* ConvertToMenu(Def::Menu* def,
+                      const std::set<Base::Model*>& excludes)
+  {
+    Menu *menu=new Menu();
+    bool foldSubItems=WillFoldSubItems(def->GetItems(),excludes);
+
+    for (std::list<Def::MenuItem*>::const_iterator iter=def->GetItems().begin();
+         iter!=def->GetItems().end();
+         ++iter) {
+      assert((*iter)!=NULL);
+
+      ConvertItem(menu,*iter,excludes,foldSubItems);
+    }
+
     return menu;
   }
 
-  MenuStrip* ConvertToMenuStrip(MenuDesc* menuDesc)
+  Menu* ConvertToMenu(Def::Menu* def)
   {
-    assert(menuDesc!=NULL);
+    std::set<Base::Model*> excludes;
+
+    return ConvertToMenu(def,excludes);
+  }
+
+  MenuStrip* ConvertToMenuStrip(Def::Menu* def,
+                                const std::set<Base::Model*>& excludes)
+  {
+    assert(def!=NULL);
 
     MenuStrip *strip=new MenuStrip();
+    size_t    pullDownCount=0;
 
     strip->SetFlex(true,false);
 
-    for (MenuDesc::MenuItemList::const_iterator iter=menuDesc->GetItems().begin();
-         iter!=menuDesc->GetItems().end();
+    for (std::list<Def::MenuItem*>::const_iterator iter=def->GetItems().begin();
+         iter!=def->GetItems().end();
          ++iter) {
       assert((*iter)!=NULL);
 
-      if (dynamic_cast<MenuItemSubDesc*>(*iter)!=NULL) {
-        MenuItemSubDesc *sub=dynamic_cast<MenuItemSubDesc*>(*iter);
+      if (dynamic_cast<Def::Menu*>(*iter)!=NULL) {
+        Def::Menu *sub=dynamic_cast<Def::Menu*>(*iter);
 
-        strip->AddPullDownMenu(sub->GetLabel(),ConvertToMenu(sub->GetMenuDesc()));
+        if (GetValidItemsCount(sub->GetItems(),excludes)>0) {
+          strip->AddPullDownMenu(sub->GetDesc().GetLabel(),
+                                 ConvertToMenu(sub));
+          pullDownCount++;
+        }
       }
       else {
         assert(false);
       }
     }
 
+    if (pullDownCount==0) {
+      delete strip;
+      strip=NULL;
+    }
+
     return strip;
   }
 
+  MenuStrip* ConvertToMenuStrip(Def::Menu* def)
+  {
+    std::set<Base::Model*> excludes;
+
+    return ConvertToMenuStrip(def,excludes);
+  }
+
 
   /* ---------- Menustrip stuff ------------------*/
 
@@ -579,7 +502,12 @@ namespace Lum {
     if (pos!=std::wstring::npos && pos+1<label.length()) {
       shortcut=label[pos+1];
       text->AddText(label.substr(0,pos));
-      text->AddText(label.substr(pos+1,1),OS::Font::underlined);
+      if (OS::display->GetTheme()->ShowKeyShortcuts()) {
+        text->AddText(label.substr(pos+1,1),OS::Font::underlined);
+      }
+      else {
+        text->AddText(label.substr(pos+1,1));
+      }
       text->AddText(label.substr(pos+2));
     }
     else {
@@ -708,8 +636,8 @@ namespace Lum {
     if (event.type==OS::MouseEvent::up &&
         PointIsIn(event) &&
         (event.button==OS::MouseEvent::button1 || event.button==OS::MouseEvent::button3)) {
-      if ((size_t)std::abs(event.x-x)<=Lum::OS::display->GetTheme()->GetMouseClickHoldSensitivity() &&
-          (size_t)std::abs(event.y-y)<=Lum::OS::display->GetTheme()->GetMouseClickHoldSensitivity()) {
+      if ((size_t)std::abs(event.x-x)<=OS::display->GetTheme()->GetMouseClickHoldSensitivity() &&
+          (size_t)std::abs(event.y-y)<=OS::display->GetTheme()->GetMouseClickHoldSensitivity()) {
         stickyMode=true;
       }
       else {
@@ -933,7 +861,8 @@ namespace Lum {
       height=std::max(height,label->GetOHeight()+2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder));
     }
 
-    if (shortcut!=NULL) {
+    if (shortcut!=NULL &&
+        OS::display->GetTheme()->ShowKeyShortcuts()) {
       if (!shortcut->IsInited()) {
         shortcut->SetParent(this);
         shortcut->SetFlex(true,true);
@@ -979,7 +908,8 @@ namespace Lum {
 
   void MenuEntry::DrawShortcut(OS::DrawInfo* /*draw*/)
   {
-    if (shortcut!=NULL) {
+    if (shortcut!=NULL &&
+        OS::display->GetTheme()->ShowKeyShortcuts()) {
       // Right align shortcut
       shortcut->Move(x3+w3-shortcut->GetOWidth(),
                      y+(height-shortcut->GetOHeight()) / 2);
@@ -1021,8 +951,14 @@ namespace Lum {
     if (pos!=std::wstring::npos && pos+1<label.length()) {
       sc=label[pos+1];
       text->AddText(label.substr(0,pos));
-      text->AddText(label.substr(pos+1,1),OS::Font::underlined);
+      if (OS::display->GetTheme()->ShowKeyShortcuts()) {
+        text->AddText(label.substr(pos+1,1),OS::Font::underlined);
+      }
+      else {
+        text->AddText(label.substr(pos+1,1));
+      }
       text->AddText(label.substr(pos+2));
+
       SetHotkey(sc);
     }
     else {
@@ -1427,31 +1363,28 @@ namespace Lum {
       height+=entry->GetOHeight();
     }
 
-    width+=OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
+    width=2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
 
     // Image
-    if (w1==0) {
-      w1=OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
-    }
-    width+=w1+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    width+=w1;
 
     //Label
-    if (w2==0) {
-      w2=OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
+    if (w1!=0 && w2!=0) {
+      width+=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
     }
-    width+=w2+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    width+=w2;
 
     // Shortcut
-    if (w3==0) {
-      w3=OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
+    if (w2!=0 && w3!=0) {
+      width+=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
     }
-    width+=w3+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    width+=w3;
 
     // Sub Image
-    if (w4==0) {
-      w4=OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
+    if (w3!=0 && w4!=0) {
+      width+=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
     }
-    width+=w4+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
+    width+=w4;
 
     for (std::list<Object*>::iterator iter=list.begin(); iter!=list.end(); ++iter) {
       MenuEntry* entry=dynamic_cast<MenuEntry*>(*iter);
@@ -1484,16 +1417,26 @@ namespace Lum {
       w4=entry->w4;
     }
 
+    // Image
     x1=x+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
 
-    // Image
-    x2=x1+w1+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
-
     //Label
-    x3=x2+w2+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    x2=x1+w1;
+    if (w1!=0) {
+      x2+=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    }
 
     // Shortcut
-    x4=x3+w3+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    x3=x2+w2;
+    if (w2!=0) {
+      x3+=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    }
+
+    // SubImage
+    x4=x3+w3;
+    if (w3!=0) {
+      x4+=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
+    }
 
     for (std::list<Object*>::iterator iter=list.begin(); iter!=list.end(); ++iter) {
       MenuEntry* entry=dynamic_cast<MenuEntry*>(*iter);
@@ -1811,7 +1754,6 @@ namespace Lum {
       window->SetType(OS::Window::typeMenuPopup);
     }
 
-
     selected=NULL;
     if (manualPos) {
       x=xPos;
@@ -1823,8 +1765,6 @@ namespace Lum {
       y=help->GetY();
       x+=reference->GetOX();
       y+=reference->GetOY()+reference->GetOHeight();
-      window->GrabMouse(true);
-      window->GrabKeyboard(true);
     }
     else if (parentMenu!=NULL) { /* submenu */
       x=parentMenu->GetWindow()->GetX()+parentMenu->GetWindow()->GetWidth()+
@@ -1847,11 +1787,6 @@ namespace Lum {
       y=window->GetY();
     }
 
-    if (strip==NULL && parentMenu==NULL) {
-      window->GrabMouse(true);
-      window->GrabKeyboard(true);
-    }
-
     x=Base::RoundRange(x,0,OS::display->GetScreenWidth()-1-window->GetWidth());
     y=Base::RoundRange(y,0,OS::display->GetScreenHeight()-1-window->GetHeight());
 
@@ -1861,6 +1796,12 @@ namespace Lum {
 
   bool Menu::Open()
   {
+    if ((strip!=NULL && reference!=NULL) ||
+        (strip==NULL && parentMenu==NULL)) {
+      window->GrabMouse(true);
+      window->GrabKeyboard(true);
+    }
+
     return window->Open(true);
   }
 
@@ -1868,7 +1809,18 @@ namespace Lum {
   {
     bool result;
 
-    result=window->Open(true);
+    if ((strip!=NULL && reference!=NULL) ||
+        (strip==NULL && parentMenu==NULL)) {
+      window->GrabMouse(true);
+      window->GrabKeyboard(true);
+    }
+
+    if (window->IsOpen()) {
+      result=window->Show(true);
+    }
+    else {
+      result=window->Open(true);
+    }
 
     if (result) {
       stickyMode=true;
@@ -2091,7 +2043,8 @@ namespace Lum {
 
     if ((mouse=dynamic_cast<OS::MouseEvent*>(event))!=NULL) {
       if (mouse->type==OS::MouseEvent::up &&
-          (mouse->button==OS::MouseEvent::button3 || mouse->button==OS::MouseEvent::button1)) {
+          (mouse->button==OS::MouseEvent::button3 ||
+           mouse->button==OS::MouseEvent::button1)) {
         menu=GetMenuWithMouseSelection();
 
         if (menu!=NULL && menu->CursorIsIn()) {
@@ -2120,7 +2073,9 @@ namespace Lum {
           }
         }
       }
-      else if (mouse->type==OS::MouseEvent::down && (mouse->button==OS::MouseEvent::button3 || mouse->button==OS::MouseEvent::button1)) {
+      else if (mouse->type==OS::MouseEvent::down &&
+               (mouse->button==OS::MouseEvent::button3 ||
+                mouse->button==OS::MouseEvent::button1)) {
         menu=GetMenuWithMouseSelection();
 
         if (menu==NULL || !menu->CursorIsIn()) {
@@ -2173,7 +2128,8 @@ namespace Lum {
         }
       }
     }
-    else if ((key=dynamic_cast<OS::KeyEvent*>(event))!=NULL && key->type==OS::KeyEvent::down) {
+    else if ((key=dynamic_cast<OS::KeyEvent*>(event))!=NULL &&
+             key->type==OS::KeyEvent::down) {
       switch (key->key) {
       case OS::keyEscape:
         EndAction();
