@@ -415,22 +415,46 @@ namespace Lum {
         draw->PopForeground();
       }
 
-      void Theme::GetMenuTypeActionPopupOffset(int& x, int& y) const
-      {
-        x=0;
-        y=0;
-      }
-
       int Theme::GetSubMenuHorizontalOffset() const
       {
         return 0;
       }
 
+      bool Theme::OptimizeMenus() const
+      {
+        return false;
+      }
+
+      size_t Theme::MaxPopupMenuEntries() const
+      {
+        return 10;
+      }
+
       bool Theme::RequestFingerFriendlyControls() const
       {
         return false;
       }
 
+      Lum::Base::Size Theme::GetFingerFriendlyMinWidth() const
+      {
+        return Lum::Base::Size(Lum::Base::Size::mm,9);
+      }
+
+      Lum::Base::Size Theme::GetFingerFriendlyMinHeight() const
+      {
+        return Lum::Base::Size(Lum::Base::Size::mm,9);
+      }
+
+      bool Theme::ShowKeyShortcuts() const
+      {
+        return true;
+      }
+
+      bool Theme::FocusOnEditableControlsOnly() const
+      {
+        return false;
+      }
+
       bool Theme::SubdialogsAlwaysFlexHoriz() const
       {
         return false;
