@@ -44,6 +44,7 @@ namespace Lum {
         eventAction(new Model::Action),
         grabCancelAction(new Model::Action()),
         menuAction(new Model::Action()),
+        isInited(false),
         open(false),
         inEventLoop(false),
         shown(false),
@@ -60,7 +61,8 @@ namespace Lum {
         backgroundDraw(NULL),
         backgroundBitmap(NULL),
         type(typeAuto),
-        grabMouse(false),grabKeyboard(false)
+        grabMouse(false),
+        grabKeyboard(false)
       {
         // no code
       }
@@ -384,6 +386,11 @@ namespace Lum {
         }
       }
 
+      bool Window::IsInited() const
+      {
+        return isInited;
+      }
+
       /**
         Opens the window.
 
@@ -392,6 +399,8 @@ namespace Lum {
       */
       bool Window::Open(bool activate)
       {
+        assert(!IsOpen());
+
         if (type==OS::Window::typeAuto) {
           if (parent!=NULL) {
             type=OS::Window::typeDialog;
@@ -401,7 +410,10 @@ namespace Lum {
           }
         }
 
-        preInitAction->Trigger();
+        if (!IsInited()) {
+          preInitAction->Trigger();
+          isInited=true;
+        }
 
         switch (type) {
         case OS::Window::typePopup:
@@ -444,13 +456,19 @@ namespace Lum {
 
         inEventLoop=true;
 
-        if (type!=typeMenu && type!=typePopup) {
+        if (type!=typeMenu &&
+            type!=typeMenuPopup &&
+            type!=typeMenuDropdown &&
+            type!=typePopup) {
           DisableParents();
         }
 
         display->MainLoop();
 
-        if (type!=typeMenu && type!=typePopup) {
+        if (type!=typeMenu &&
+            type!=typeMenuPopup &&
+            type!=typeMenuDropdown &&
+            type!=typePopup) {
           EnableParents();
         }
 
@@ -828,18 +846,22 @@ namespace Lum {
 
       void Window::MouseGrabOn()
       {
+        // no code
       }
 
       void Window::MouseGrabOff()
       {
+        // no code
       }
 
       void Window::KeyboardGrabOn()
       {
+        // no code
       }
 
       void Window::KeyboardGrabOff()
       {
+        // no code
       }
 
       bool Window::SetFullScreen()
