@@ -222,17 +222,22 @@ namespace Lum {
         : image(image)
       {
         switch (image) {
-        case Theme::closeStockImage:
-        case Theme::addStockImage:
-        case Theme::removeStockImage:
-        case Theme::editStockImage:
+        case Theme::imageClose:
+        case Theme::imageAdd:
+        case Theme::imageRemove:
+        case Theme::imageEdit:
           width=1;
           height=1;
           break;
-        case Theme::positiveStockImage:
-        case Theme::negativeStockImage:
-        case Theme::defaultStockImage:
-        case Theme::helpStockImage:
+        case Theme::imagePositive:
+        case Theme::imageNegative:
+        case Theme::imageDefault:
+        case Theme::imageHelp:
+        case Theme::imageSave:
+        case Theme::imageMediaRecord:
+        case Theme::imageMediaPlay:
+        case Theme::imageMediaPause:
+        case Theme::imageMediaStop:
           width=0;
           height=0;
           break;
@@ -268,22 +273,27 @@ namespace Lum {
           for (int j=y; j<y+h; ++j) {
 
             switch (image) {
-            case Theme::closeStockImage:
+            case Theme::imageClose:
               draw->DrawString(i,j,L"X");
               break;
-            case Theme::addStockImage:
+            case Theme::imageAdd:
               draw->DrawString(i,j,L"+");
               break;
-            case Theme::removeStockImage:
+            case Theme::imageRemove:
               draw->DrawString(i,j,L"-");
               break;
-            case Theme::editStockImage:
+            case Theme::imageEdit:
               draw->DrawString(i,j,L"v");
               break;
-            case Theme::positiveStockImage:
-            case Theme::negativeStockImage:
-            case Theme::defaultStockImage:
-            case Theme::helpStockImage:
+            case Theme::imagePositive:
+            case Theme::imageNegative:
+            case Theme::imageDefault:
+            case Theme::imageHelp:
+            case Theme::imageSave:
+            case Theme::imageMediaRecord:
+            case Theme::imageMediaPlay:
+            case Theme::imageMediaPause:
+            case Theme::imageMediaStop:
               break;
             }
           }
@@ -879,7 +889,7 @@ namespace Lum {
         image[Display::checkImageIndex]=new TextImage(Display::checkImageIndex);
         image[Display::ledImageIndex]=new TextImage(Display::ledImageIndex);
 
-        stockImage[closeStockImage]=new TextStockImage(closeStockImage);
+        stockImage[imageClose]=new TextStockImage(imageClose);
 
       }
 
