@@ -42,6 +42,8 @@
 #define MENU_SYSTEMMINIMIZE       19
 #define MENU_SYSTEMRESTOREE       20
 
+#define LBCP_BORDER_NOSCROLL       0
+
 namespace Lum {
   namespace OS {
     namespace Win32 {
@@ -51,6 +53,7 @@ namespace Lum {
       static HTHEME  comboboxTheme;
       static HTHEME  editTheme;
       static HTHEME  headerTheme;
+      static HTHEME  listboxTheme;
       static HTHEME  listviewTheme;
       static HTHEME  menuTheme;
       static HTHEME  progressTheme;
@@ -165,6 +168,7 @@ namespace Lum {
               comboboxTheme=MyOpenThemeData(dynamic_cast<Display*>(display)->appWindow,L"Combobox");
               editTheme=MyOpenThemeData(dynamic_cast<Display*>(display)->appWindow,L"Edit");
               headerTheme=MyOpenThemeData(dynamic_cast<Display*>(display)->appWindow,L"Header");
+              listboxTheme=MyOpenThemeData(dynamic_cast<Display*>(display)->appWindow,L"Listbox");
               listviewTheme=MyOpenThemeData(dynamic_cast<Display*>(display)->appWindow,L"Listview");
               menuTheme=MyOpenThemeData(dynamic_cast<Display*>(display)->appWindow,L"Menu");
               progressTheme=MyOpenThemeData(dynamic_cast<Display*>(display)->appWindow,L"Progress");
@@ -345,6 +349,7 @@ namespace Lum {
             height=GetSystemMetrics(SM_CYMENUCHECK);
           }
           break;
+          /*
         case Display::closeImageIndex:
           if (HasTheming() && menuTheme!=NULL) {
             SIZE size;
@@ -358,7 +363,7 @@ namespace Lum {
             width=GetSystemMetrics(SM_CXMENUCHECK)-4;
             height=GetSystemMetrics(SM_CYMENUCHECK)-4;
           }
-          break;
+          break;*/
         case Display::radioImageIndex:
           width=GetSystemMetrics(SM_CXMENUCHECK);
           height=GetSystemMetrics(SM_CYMENUCHECK);
@@ -835,6 +840,7 @@ namespace Lum {
                                             DFCS_BUTTONRADIO | (draw->selected ? DFCS_CHECKED : 0));
           }
           break;
+#if 0
         case Display::closeImageIndex:
           if (HasTheming() && menuTheme!=NULL) {
             /* ignore */ MyDrawThemeBackground(menuTheme,dc,MENU_SYSTEMCLOSE,1,&rect,NULL);
@@ -852,6 +858,7 @@ namespace Lum {
             draw->PopPen();
           }
           break;
+#endif          
         case Display::radioImageIndex:
           if (HasTheming()) {
             if (draw->selected) {
@@ -1192,10 +1199,26 @@ namespace Lum {
           bottomBorder=topBorder;
           break;
         case Display::scrolledBackgroundFillIndex:
-          leftBorder=GetSystemMetrics(SM_CXEDGE);
-          rightBorder=leftBorder;
-          topBorder=GetSystemMetrics(SM_CYEDGE);
-          bottomBorder=topBorder;
+          if (HasTheming()) {
+            RECT content,extent;
+
+            content.left=0;
+            content.right=0;
+            content.top=0;
+            content.bottom=0;
+            MyGetThemeBackgroundExtent(listboxTheme,NULL,LBCP_BORDER_NOSCROLL,0,&content,&extent);
+            leftBorder=-extent.left;
+            rightBorder=extent.right;
+            topBorder=-extent.top;
+            bottomBorder=extent.bottom;
+            transparentBorder=true;
+          }
+          else {
+            leftBorder=GetSystemMetrics(SM_CXEDGE);
+            rightBorder=leftBorder;
+            topBorder=GetSystemMetrics(SM_CYEDGE);
+            bottomBorder=topBorder;
+          }
           break;
         case Display::boxedBackgroundFillIndex:
           leftBorder=GetSystemMetrics(SM_CXEDGE);
@@ -2116,15 +2139,34 @@ namespace Lum {
           /* ignore */ FillRect(dc,&rect,::GetSysColorBrush(COLOR_WINDOW));
           return;
         case Display::scrolledBackgroundFillIndex:
-          /* ignore */ FillRect(dc,&rect,::GetSysColorBrush(COLOR_3DFACE));
+          if (HasTheming()) {
+            RECT content,clip;
 
-          rect.left=xOff;
-          rect.top=yOff;
-          rect.right=xOff+width;
-          rect.bottom=yOff+height;
+            content.left=xOff;
+            content.right=xOff+width;
+            content.top=yOff;
+            content.bottom=yOff+height;
 
-          /* ignore */ DrawEdge(dc,&rect,EDGE_SUNKEN,BF_RECT);
-          return;
+            clip.left=x;
+            clip.right=x+w;
+            clip.top=y;
+            clip.bottom=y+h;
+
+            MyDrawThemeBackground(listboxTheme,dc,LBCP_BORDER_NOSCROLL,0,&content,&clip);
+
+            return;
+          }
+          else {
+            /* ignore */ FillRect(dc,&rect,::GetSysColorBrush(COLOR_3DFACE));
+
+            rect.left=xOff;
+            rect.top=yOff;
+            rect.right=xOff+width;
+            rect.bottom=yOff+height;
+
+            /* ignore */ DrawEdge(dc,&rect,EDGE_SUNKEN,BF_RECT);
+            return;
+          }
         case Display::hscrollBackgroundFillIndex:
         case Display::vscrollBackgroundFillIndex:
           return;
@@ -2531,7 +2573,7 @@ namespace Lum {
         image[Display::menuSubImageIndex]=new ThemeImage(Display::menuSubImageIndex);
         image[Display::menuCheckImageIndex]=new ThemeImage(Display::menuCheckImageIndex);
         image[Display::menuRadioImageIndex]=new ThemeImage(Display::menuRadioImageIndex);
-        image[Display::closeImageIndex]=new ThemeImage(Display::closeImageIndex);
+        //image[Display::closeImageIndex]=new ThemeImage(Display::closeImageIndex);
         image[Display::radioImageIndex]=new ThemeImage(Display::radioImageIndex);
         image[Display::checkImageIndex]=new ThemeImage(Display::checkImageIndex);
         image[Display::ledImageIndex]=new ThemeImage(Display::ledImageIndex);
