@@ -270,7 +270,6 @@ namespace Lum {
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
-        grab(false),
         oldPress(0),lastPress(0),thisPress(0),
         drawn(false),queueFocus(false),
         window(0)
@@ -282,7 +281,7 @@ namespace Lum {
       /**
         Grabs the mouse cursor and keyboard.
       */
-      void Window::GrabOn()
+      void Window::MouseGrabOn()
       {
         assert(grabWindow==NULL);
         HWND grabHWND;
@@ -307,7 +306,7 @@ namespace Lum {
       /**
         Releases the grab of the mouse cursor and the keyboard.
       */
-      void Window::GrabOff()
+      void Window::MouseGrabOff()
       {
         assert(grabWindow!=NULL);
 
@@ -318,22 +317,6 @@ namespace Lum {
         grabWindow=NULL;
       }
 
-      void Window::Grab(bool grab)
-      {
-        if (this->grab==grab) {
-          return;
-        }
-        this->grab=grab;
-        if (IsOpen()) {
-          if (this->grab) {
-            GrabOn();
-          }
-          else {
-            GrabOff();
-          }
-        }
-      }
-
       void Window::SetTitle(const std::wstring& name)
       {
         OS::Base::Window::SetTitle(name);
@@ -380,11 +363,9 @@ namespace Lum {
 
         switch (type) {
         case typeMenu:
-          flags=WS_POPUP;
-          break;
+        case typeMenuDropdown:
+        case typeMenuPopup:
         case typePopup:
-          flags=WS_POPUP;
-          break;
         case typeSplash:
           flags=WS_POPUP;
           break;
@@ -406,6 +387,8 @@ namespace Lum {
           exFlags=WS_EX_TOOLWINDOW;
           break;
         case typeMenu:
+        case typeMenuDropdown:
+        case typeMenuPopup:
         case typePopup:
           exFlags=WS_EX_NOACTIVATE|WS_EX_TOPMOST;
           break;
@@ -469,7 +452,11 @@ namespace Lum {
         draw=OS::driver->CreateDrawInfo(this);
         draw->PushClip(0,0,display->GetScreenWidth(),display->GetScreenHeight());
 
-        if ((type==typeMenu || type==typePopup) && parent!=NULL) {
+        if ((type==typeMenu ||
+             type==typeMenuDropdown ||
+             type==typeMenuPopup ||
+             type==typePopup) &&
+            parent!=NULL) {
           /* ignore */ ::ShowWindow(window,SW_SHOWNOACTIVATE);
           if (this->parent!=NULL) {
             dynamic_cast<Window*>(this->parent)->TriggerGrabCancel();
@@ -496,8 +483,11 @@ namespace Lum {
 
           hwnd=window;
 
-          if (grab) {
-            GrabOff();
+          if (grabMouse) {
+            MouseGrabOff();
+          }
+          if (grabKeyboard) {
+            KeyboardGrabOff();
           }
 
           /*
@@ -519,6 +509,8 @@ namespace Lum {
           if (parent!=NULL) {
             switch (type) {
             case typeMenu:
+            case typeMenuDropdown:
+            case typeMenuPopup:
             case typePopup:
               break;
             default:
@@ -693,7 +685,7 @@ namespace Lum {
           }
 
           if (msg==WM_MOUSEMOVE && type==typeMenu && parent==NULL) {
-            // HAck: If not done, we have a hourglass cursor for this special popup case!?
+            // Hack: If not done, we have a hourglass cursor for this special popup case!?
             ::SetCursor(LoadCursor(0,IDC_ARROW));
           }
 
@@ -721,8 +713,8 @@ namespace Lum {
           else {
             if (!IsShown()) {
               TriggerMaped();
-              if (grab) {
-                GrabOn();
+              if (grabMouse) {
+                MouseGrabOn();
               }
             }
           }
@@ -760,7 +752,10 @@ namespace Lum {
           break;
         case WM_MOUSEACTIVATE:
           //We should not get activated
-          if ((type==typeMenu || type==typePopup) && parent!=NULL) {
+          if ((type==typeMenu ||
+               type==typeMenuDropdown ||
+               type==typeMenuPopup ||
+               type==typePopup) && parent!=NULL) {
             return MA_NOACTIVATE;
           }
           break;
