@@ -63,6 +63,7 @@
 
 #include <Lum/Images/Image.h>
 
+#include <Lum/OS/Base/Behaviour.h>
 #include <Lum/OS/Base/Theme.h>
 
 #include <Lum/OS/EventLoopUnix.h>
@@ -80,6 +81,10 @@
   #include <Lum/OS/X11/GtkTheme.h>
 #endif
 
+#if defined(LUM_HAVE_LIB_HILDON)
+  #include <Lum/OS/Hildon/Behaviour.h>
+#endif
+
 #if defined(CAIRO_HAS_XLIB_SURFACE)
   #include <Lum/OS/Cairo/Display.h>
 #endif
@@ -225,6 +230,12 @@ namespace Lum {
                         PropModeReplace,(unsigned char*)&value,1);
       }
 
+      void Display::SetIntegerProperty(Window* window, Atom property, int value)
+      {
+        XChangeProperty(display,window->window,property,XA_INTEGER,32,
+                        PropModeReplace,(unsigned char*)&value,1);
+      }
+
       void Display::SetEmbedInfoProperty(::Window window)
       {
         uint32_t data[2];
@@ -886,7 +897,10 @@ namespace Lum {
           return false;
         }
 
-        g_thread_init(NULL);
+        if (!g_thread_supported ()) {
+          g_thread_init (NULL);
+        }
+
         gdk_threads_init();
 
         display=GDK_DISPLAY_XDISPLAY(gdk_display_get_default());
@@ -1029,18 +1043,24 @@ namespace Lum {
         D.bigChess:=d.CreateBitmapPattern(D.bigChessPattern,D.bigChessWidth,D.bigChessHeight);
 
                       */
-
 #if defined(HAVE_LIB_GTK)
         if (((driver->GetDriverName()==L"X11" ||
              driver->GetDriverName()==L"CairoX11")) &&
              (getenv("ILLUMINATION_THEME")==NULL ||
               strcmp(getenv("ILLUMINATION_THEME"),"X11"))!=0) {
+#if defined (LUM_HAVE_LIB_HILDON)
+          behaviour=new OS::Hildon::Behaviour();
+#else
+          behaviour=new OS::Base::DefaultBehaviour();
+#endif
           theme=new GtkTheme(this);
         }
         else {
+          behaviour=new OS::Base::DefaultBehaviour();
           theme=new OS::Base::DefaultTheme(this);
         }
 #else
+        behaviour=new OS::Base::DefaultBehaviour();
         theme=new OS::Base::DefaultTheme(this);
 #endif
 
@@ -1223,7 +1243,6 @@ namespace Lum {
           std::cerr << "Cannot create system DBUS connection!" << std::endl;
         }
 #endif
-
         return true;
       }
 
@@ -1281,7 +1300,7 @@ namespace Lum {
           }
         }
 
-#if defined(HAVE_LIB_CAIRO) && defined(CAIRO_HAS_XLIB_SURFACE)
+#if defined(LUM_HAVE_LIB_CAIRO) && defined(CAIRO_HAS_XLIB_SURFACE)
         Cairo::FreeGlobalCairo();
         Cairo::FreeGlobalSurface();
 #endif
@@ -1294,7 +1313,7 @@ namespace Lum {
         }
 #endif
 
-#if defined(HAVE_LIB_CAIRO) && defined(CAIRO_HAS_XLIB_SURFACE)
+#if defined(LUM_HAVE_LIB_CAIRO) && defined(CAIRO_HAS_XLIB_SURFACE)
         //cairo_debug_reset_static_data();
 #endif
       }
@@ -1906,7 +1925,6 @@ namespace Lum {
         };
 
         std::cout << "CallbackSaveYourself" << std::endl;
-
         vals.program->value=(void*)const_cast<wchar_t*>(programName.c_str());
         vals.program->length=programName.length();
 
