@@ -568,48 +568,29 @@ namespace Lum {
           int       tmp1,tmp2;
 #endif
 
-        display=dynamic_cast< ::Lum::OS::X11::Display*>(d)->display;
-        scrNum=dynamic_cast< ::Lum::OS::X11::Display*>(d)->scrNum;
-        visual=dynamic_cast< ::Lum::OS::X11::Display*>(d)->visual;
-        depth=dynamic_cast< ::Lum::OS::X11::Display*>(d)->GetColorDepth();
-        colorMap=dynamic_cast< ::Lum::OS::X11::Display*>(d)->colorMap;
+        display=dynamic_cast< X11::Display*>(d)->display;
+        scrNum=dynamic_cast< X11::Display*>(d)->scrNum;
+        visual=dynamic_cast< X11::Display*>(d)->visual;
+        depth=dynamic_cast< X11::Display*>(d)->GetColorDepth();
+        colorMap=dynamic_cast< X11::Display*>(d)->colorMap;
 
-        if (depth>=24 && XMatchVisualInfo(display,scrNum,24,TrueColor,&info)!=0) {
-          visual=info.visual;
-          depth=24;
-          colorMap=XCreateColormap(display,
-                                   XDefaultRootWindow(display),
-                                   visual,
-                                   AllocNone);
+        while (depth>=8) {
+          if (XMatchVisualInfo(display,scrNum,depth,TrueColor,&info)!=0) {
+            visual=info.visual;
+            colorMap=XCreateColormap(display,
+                                     XDefaultRootWindow(display),
+                                     visual,
+                                     AllocNone);
 
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->visual=visual;
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->SetColorDepth(depth);
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->colorMap=colorMap;
-        }
-        else if (depth>=16 && XMatchVisualInfo(display,scrNum,16,TrueColor,&info)!=0) {
-          visual=info.visual;
-          depth=16;
-          colorMap=XCreateColormap(display,
-                                   XDefaultRootWindow(display),
-                                   visual,
-                                   AllocNone);
+            dynamic_cast< X11::Display*>(d)->visual=visual;
+            dynamic_cast< X11::Display*>(d)->SetColorDepth(depth);
+            dynamic_cast< X11::Display*>(d)->colorMap=colorMap;
 
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->visual=visual;
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->SetColorDepth(depth);
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->colorMap=colorMap;
-        }
-        else if (depth>=8 && XMatchVisualInfo(display,scrNum,8,TrueColor,&info)!=0) {
-          // untested!!!
-          visual=info.visual;
-          depth=8;
-          colorMap=XCreateColormap(display,
-                                   XDefaultRootWindow(display),
-                                   visual,
-                                   AllocNone);
-
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->visual=visual;
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->SetColorDepth(depth);
-          dynamic_cast< ::Lum::OS::X11::Display*>(d)->colorMap=colorMap;
+            break;
+          }
+          else  {
+            depth-=8;
+          }
         }
 
 #if defined(HAVE_LIB_XFT2)
