@@ -126,7 +126,10 @@ namespace Lum {
   {
     // Tell the window, that this object hides
     // Dialog may delgate focus or other things
-    if (visible && GetWindow()!=NULL && dynamic_cast<Window*>(GetWindow()->GetMaster())!=NULL) {
+    if (visible &&
+        GetWindow()!=NULL &&
+        GetWindow()->GetMaster()!=NULL &&
+        dynamic_cast<Window*>(GetWindow()->GetMaster())!=NULL) {
       dynamic_cast<Window*>(GetWindow()->GetMaster())->ObjectHides(this);
     }
 
@@ -342,6 +345,14 @@ namespace Lum {
     return this;
   }
 
+  Object* Object::SetConstraint(Constraint constraint,
+                                const Base::Size& size)
+  {
+    constraints.push_back(ConstraintSize(constraint,size));
+
+    return this;
+  }
+
   /**
     Set the width of the object.
     "Mode" defines the interpretation of the given value.
@@ -420,6 +431,37 @@ namespace Lum {
     return this;
   }
 
+  Object* Object::SetMinWidth(const Base::Size& size)
+  {
+    return SetConstraint(constraintMinWidth,size);
+  }
+
+  Object* Object::SetMinHeight(const Base::Size& size)
+  {
+    return SetConstraint(constraintMinHeight,size);
+  }
+
+  Object* Object::SetWidth(const Base::Size& size)
+  {
+    return SetConstraint(constraintWidth,size);
+  }
+
+  Object* Object::SetHeight(const Base::Size& size)
+  {
+    return SetConstraint(constraintHeight,size);
+  }
+
+  Object* Object::SetMaxWidth(const Base::Size& size)
+  {
+    return SetConstraint(constraintMaxWidth,size);
+  }
+
+  Object* Object::SetMaxHeight(const Base::Size& size)
+  {
+    return SetConstraint(constraintMaxHeight,size);
+  }
+
+
   Object* Object::SetFlex(bool horizontal, bool vertical)
   {
     horizontalFlex=horizontal;
@@ -1346,7 +1388,7 @@ namespace Lum {
     oldOWidth=oWidth;
 
     if (horizontalFlex) {
-      oWidth=std::max(width,oMinWidth);
+      oWidth=std::min(std::max(width,oMinWidth),oMaxWidth);
       this->width=oWidth;
       if (background.Valid()) {
         this->width-=background->leftBorder+background->rightBorder;
@@ -1365,7 +1407,7 @@ namespace Lum {
     oldOHeight=oHeight;
 
     if (verticalFlex) {
-      oHeight=std::max(height,oMinHeight);
+      oHeight=std::min(std::max(height,oMinHeight),oMaxHeight);
       this->height=oHeight;
       if (background.Valid()) {
         this->height-=background->topBorder+background->bottomBorder;
@@ -2070,6 +2112,41 @@ namespace Lum {
     return false;
   }
 
+  void Object::GetModels(std::set<Base::Model*>& models)
+  {
+    class ModelVisitor : public Visitor
+    {
+    private:
+     std::set<Base::Model*>& models;
+
+    public:
+      ModelVisitor(std::set<Base::Model*>& models)
+       : models(models)
+      {
+        // no code
+      }
+
+      bool Visit(Object* object)
+      {
+        Control* control=dynamic_cast<Control*>(object);
+
+        if (control!=NULL) {
+          Base::Model *model=control->GetModel();
+
+          if (model!=NULL) {
+            models.insert(model);
+          }
+        }
+
+        return object->VisitChildren(*this,false);
+      }
+    };
+
+    ModelVisitor visitor(models);
+
+    visitor.Visit(this);
+  }
+
   Control::~Control()
   {
     // no code
