@@ -25,7 +25,7 @@ namespace Lum {
   : boolModel(NULL),sizeTModel(NULL),index(1),active(active)
   {
     SetCanFocus(active);
-    if (active) {
+    if (active && !OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
       RequestFocus();
       SetRedrawOnMouseActive(true);
     }
