@@ -136,7 +136,7 @@ namespace Lum {
 
   String::String()
   : textAlign(left),textWidth(256),baseline(false),
-    visWidth(20),
+    visWidth(std::max(20u,OS::display->GetFont()->height*5)),
     offset(0),cursor(0),
     markA((size_t)-1),markB((size_t)-1),
     font(OS::display->GetFont()),
@@ -144,6 +144,7 @@ namespace Lum {
     selected(false),
     readOnly(false),
     cursorVisible(false),
+    showClearButton(false),
     mode(normal),
     blinkAction(new Model::Action),
     cutAction(new Model::Action),
@@ -254,18 +255,31 @@ namespace Lum {
     focusOutAction=action;
   }
 
-  void String::SetMode(Mode mode)
+  String* String::SetMode(Mode mode)
   {
     this->mode=mode;
 
     Redraw();
+
+    return this;
   }
 
-  void String::SetAlignment(Alignment alignment)
+  String* String::SetAlignment(Alignment alignment)
   {
     textAlign=alignment;
 
     Redraw();
+
+    return this;
+  }
+
+  String* String::ShowClearButton(bool show)
+  {
+    showClearButton=show;
+
+    Redraw();
+
+    return this;
   }
 
   Model::Action* String::GetCursorUpAction() const
@@ -900,6 +914,10 @@ namespace Lum {
     xPos=this->x;
     fieldWidth=width;
 
+    if (showClearButton) {
+      fieldWidth-=font->height;
+    }
+
     /* Calculate starting pos depending on alignment */
     if (textAlign==left) {
       textPos=xPos;
@@ -1048,6 +1066,17 @@ namespace Lum {
       }
     }
 
+    if (showClearButton) {
+      draw->PushForeground(OS::Display::fillColor);
+      draw->PushPen(5);
+
+      draw->DrawLine(this->x+fieldWidth,yOff,this->x+fieldWidth+font->height,yOff+font->height);
+      draw->DrawLine(this->x+fieldWidth+font->height,yOff,this->x+fieldWidth,yOff+font->height);
+
+      draw->PopPen();
+      draw->PopForeground();
+    }
+
     draw->PopClip();
 
     draw->focused=false;
@@ -1098,7 +1127,10 @@ namespace Lum {
     if (event.type==OS::MouseEvent::down && PointIsIn(event) && event.button==OS::MouseEvent::button1) {
       OS::Window* window=GetWindow();
 
-      if (window->IsDoubleClicked()) {
+      if (showClearButton && event.x>=this->x+(int)(this->width-1-font->height)) {
+        ActionEraseAll();
+      }
+      else  if (window->IsDoubleClicked()) {
         SelectAll();
         Redraw();
       }
