@@ -116,11 +116,6 @@ namespace Lum {
     table->SetSelection(selection);
   }
 
-  void Table::SetSelectionAction(Model::Action* action)
-  {
-    table->SetSelectionAction(action);
-  }
-
   void Table::SetDoubleClickAction(Model::Action* action)
   {
     table->SetDoubleClickAction(action);
@@ -199,24 +194,30 @@ namespace Lum {
 
   void Table::Layout()
   {
-    if (hVisible && table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal()) {
+    if (hVisible &&
+        (!table->GetHAdjustment()->IsValid() ||
+         table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal())) {
       hScroller->Hide();
       hVisible=false;
     }
-    else if (!hVisible && table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) {
+    else if (!hVisible &&
+             table->GetHAdjustment()->IsValid() &&
+             table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) {
       hVisible=true;
     }
 
-    if (vVisible && table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal()) {
+    if (vVisible &&
+        (!table->GetVAdjustment()->IsValid() ||
+         table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal())) {
       vScroller->Hide();
       vVisible=false;
     }
-    else if (!vVisible && table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal()) {
+    else if (!vVisible &&
+             table->GetVAdjustment()->IsValid() &&
+             table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal()) {
       vVisible=true;
     }
 
-    table->CalculateDimension();
-
     size_t tWidth,tHeight;
 
     tWidth=width;
@@ -279,10 +280,18 @@ namespace Lum {
         return;
       }
       else if (model==refreshAction && refreshAction->IsFinished()) {
-        if ((hVisible && table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal()) ||
-            (!hVisible && table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) ||
-            (vVisible && table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal()) ||
-            (!vVisible && table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal())) {
+        if ((hVisible &&
+             (!table->GetHAdjustment()->IsValid() ||
+              table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal())) ||
+            (!hVisible &&
+             table->GetHAdjustment()->IsValid() &&
+             table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) ||
+            (vVisible &&
+             (!table->GetVAdjustment()->IsValid() ||
+              table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal())) ||
+            (!vVisible &&
+             table->GetVAdjustment()->IsValid() &&
+             table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal())) {
           SetRelayout();
           Redraw();
         }
