@@ -29,8 +29,9 @@
 
 #include <Lum/OS/Manager/KeyboardManager.h>
 
+#include <Lum/Menu.h>
 #include <Lum/Panel.h>
-#include <iostream>
+
 #define MENU_TIMEOUT 2
 
 namespace Lum {
@@ -549,12 +550,25 @@ namespace Lum {
 
     object=GetPosObject(posModeMenu);
     if (object!=NULL) {
-      OS::Window* menu;
+      OS::Window* window;
+      Menu*       menu=NULL;
+
+      window=object->GetMenu();
+
+      if (window!=NULL) {
+        menu=dynamic_cast<Menu*>(window->GetMaster());
+      }
 
-      menu=object->GetMenu();
       if (menu!=NULL) {
         object->PrepareMenu();
-        /* ignore */ menu->Open(true);
+        /* Ignore */ menu->OpenInStickyMode();
+
+        return true;
+      }
+      else if (window!=NULL) {
+        object->PrepareMenu();
+        /* ignore */ window->Open(true);
+
         return true;
       }
     }
